==> jonas-JONAS_4_6_4.tar.gz: jonas-JONAS_4_6_4/jonas/src/org/objectweb/jonas_ejb/deployment/api/JonasEjbjarSchemas.java <==
/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or 1any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Initial developer: Philippe Coq
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas_ejb.deployment.api;

import org.objectweb.jonas_lib.deployment.api.CommonsSchemas;

/**
 * This class defines the declarations of Schemas for ejb-jar.xml and jonas-ejb-jar.xml
 * @author Philippe Coq
 */
public class JonasEjbjarSchemas extends CommonsSchemas {

    /**
     * List of schemas used for ejb-jar.xml
     */
    public static final String[] JONAS_EJBJAR_SCHEMAS = new String[] {
        "jonas-ejb-jar_4_0.xsd",
        "jonas-ejb-jar_4_1.xsd",
        "jonas-ejb-jar_4_1_2.xsd",
        "jonas-ejb-jar_4_1_4.xsd",
        "jonas-ejb-jar_4_2.xsd",
        "jonas-ejb-jar_4_3.xsd",
        "jonas-ejb-jar_4_6.xsd"
    };


    /**
     * Build a new object for Schemas handling
     */
    public JonasEjbjarSchemas() {
        super();
        // Required ejb schemas
        addSchemas(EjbjarSchemas.EJBJAR_SCHEMAS);
        addSchemas(JONAS_EJBJAR_SCHEMAS);
    }


    /**
     * @return Returns the last Schema
     */
    public static String getLastSchema() {
        return JONAS_EJBJAR_SCHEMAS[JONAS_EJBJAR_SCHEMAS.length - 1];
    }

}

==> jonas-JONAS_4_10_9.tar.gz: jonas-JONAS_4_10_9/jonas/src/org/objectweb/jonas_ejb/deployment/api/JonasEjbjarSchemas.java <==
/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999-2008 Bull S.A.S.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or 1any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Initial developer: Philippe Coq
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas_ejb.deployment.api;

import org.objectweb.jonas_lib.deployment.api.CommonsSchemas;

/**
 * This class defines the declarations of Schemas for ejb-jar.xml and jonas-ejb-jar.xml
 * @author Philippe Coq
 */
public class JonasEjbjarSchemas extends CommonsSchemas {

    /**
     * List of schemas used for ejb-jar.xml
     */
    public static final String[] JONAS_EJBJAR_SCHEMAS = new String[] {
        "jonas-ejb-jar_4_0.xsd",
        "jonas-ejb-jar_4_1.xsd",
        "jonas-ejb-jar_4_1_2.xsd",
        "jonas-ejb-jar_4_1_4.xsd",
        "jonas-ejb-jar_4_2.xsd",
        "jonas-ejb-jar_4_3.xsd",
        "jonas-ejb-jar_4_6.xsd",
        "jonas-ejb-jar_4_7.xsd",
        "jonas-ejb-jar_4_8.xsd",
        "jonas-ejb-jar_4_10.xsd",
    };


    /**
     * Build a new object for Schemas handling
     */
    public JonasEjbjarSchemas() {
        super();
        // Required ejb schemas
        addSchemas(EjbjarSchemas.EJBJAR_SCHEMAS);
        addSchemas(JONAS_EJBJAR_SCHEMAS);
    }


    /**
     * @return Returns the last Schema
     */
    public static String getLastSchema() {
        return JONAS_EJBJAR_SCHEMAS[JONAS_EJBJAR_SCHEMAS.length - 1];
    }

}
